pylogpro - 更加简洁的python日志记录工具
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

实例
^^^^

.. code:: python

    import pylogpro

    loger = pylogpro.Loger()
    loger.set_logfile("log.txt")
    loger.info("first log.")
    loger.close()

关于
^^^^

| 一个比logging更加方便的python日志记录工具
| Powered by 31core.
